@@ -31,6 +31,7 @@ from UEFI.Filesystems import GrubShellBootableIsoImage
 from UEFI.SignedBinary import SignedBinary
 from UEFI.Qemu import QemuEfiMachine, QemuEfiVariant, QemuEfiFlashSize
 from UEFI import Qemu
+from UEFI.VarStore import init_shell_entry
 
 EfiArchToGrubArch = {
     'X64': "x86_64",
@@ -161,6 +162,7 @@ class BootToShellTest(unittest.TestCase):
     )
     def test_aavmf(self):
         q = Qemu.QemuCommand(QemuEfiMachine.AAVMF)
+        init_shell_entry(q.pflash.varfile.name, 'ArmVirt')
         self.run_cmd_check_shell(q.command)
 
     @unittest.skipUnless(
@@ -208,6 +210,7 @@ class BootToShellTest(unittest.TestCase):
             QemuEfiMachine.AAVMF,
             variant=QemuEfiVariant.MS,
         )
+        init_shell_entry(q.pflash.varfile.name, 'ArmVirt')
         self.run_cmd_check_shell(q.command, should_start=False)
 
     @unittest.skipUnless(
@@ -221,6 +224,7 @@ class BootToShellTest(unittest.TestCase):
             QemuEfiMachine.AAVMF,
             variant=QemuEfiVariant.MS_STRICTNX,
         )
+        init_shell_entry(q.pflash.varfile.name, 'ArmVirt')
         self.run_cmd_check_shell(q.command, should_start=False)
 
     @unittest.skipUnless(
@@ -300,6 +304,7 @@ class BootToShellTest(unittest.TestCase):
 
     def test_aavmf32(self):
         q = Qemu.QemuCommand(QemuEfiMachine.AAVMF32)
+        init_shell_entry(q.pflash.varfile.name, 'ArmVirt')
         self.run_cmd_check_shell(q.command)
 
     @unittest.skipUnless(
@@ -307,6 +312,7 @@ class BootToShellTest(unittest.TestCase):
     )
     def test_loongarch64(self):
         q = Qemu.QemuCommand(QemuEfiMachine.LOONGARCH64)
+        init_shell_entry(q.pflash.varfile.name, 'LoongArchVirt')
         self.run_cmd_check_shell(q.command)
 
     @unittest.skipUnless(
@@ -317,6 +323,7 @@ class BootToShellTest(unittest.TestCase):
             QemuEfiMachine.OVMF_PC,
             flash_size=QemuEfiFlashSize.SIZE_4MB,
         )
+        init_shell_entry(q.pflash.varfile.name, 'Ovmf')
         self.run_cmd_check_shell(q.command)
 
     @unittest.skipUnless(
@@ -327,6 +334,7 @@ class BootToShellTest(unittest.TestCase):
             QemuEfiMachine.OVMF_Q35,
             flash_size=QemuEfiFlashSize.SIZE_4MB,
         )
+        init_shell_entry(q.pflash.varfile.name, 'Ovmf')
         self.run_cmd_check_shell(q.command)
 
     @unittest.skipUnless(
@@ -339,6 +347,7 @@ class BootToShellTest(unittest.TestCase):
             variant=QemuEfiVariant.MS,
             flash_size=QemuEfiFlashSize.SIZE_4MB,
         )
+        init_shell_entry(q.pflash.varfile.name, 'Ovmf')
         self.run_cmd_check_shell(q.command, should_start=False)
 
     @unittest.skipUnless(
@@ -351,6 +360,7 @@ class BootToShellTest(unittest.TestCase):
             variant=QemuEfiVariant.MS_STRICTNX,
             flash_size=QemuEfiFlashSize.SIZE_4MB,
         )
+        init_shell_entry(q.pflash.varfile.name, 'Ovmf')
         self.run_cmd_check_shell(q.command, should_start=False)
 
     @unittest.skipUnless(
@@ -426,6 +436,7 @@ class BootToShellTest(unittest.TestCase):
             QemuEfiMachine.OVMF_Q35,
             variant=QemuEfiVariant.SNAKEOIL,
         )
+        init_shell_entry(q.pflash.varfile.name, 'Ovmf')
         self.run_cmd_check_shell(q.command, should_start=False)
 
     @unittest.skipUnless(
@@ -474,6 +485,7 @@ class BootToShellTest(unittest.TestCase):
             QemuEfiMachine.OVMF32_PC,
             flash_size=QemuEfiFlashSize.SIZE_4MB,
         )
+        init_shell_entry(q.pflash.varfile.name, 'Ovmf')
         self.run_cmd_check_shell(q.command)
 
     def test_ovmf32_4m_q35(self):
@@ -481,6 +493,7 @@ class BootToShellTest(unittest.TestCase):
             QemuEfiMachine.OVMF32_Q35,
             flash_size=QemuEfiFlashSize.SIZE_4MB,
         )
+        init_shell_entry(q.pflash.varfile.name, 'Ovmf')
         self.run_cmd_check_shell(q.command)
 
     @unittest.skipUnless(
